@REM ***************************************************************
@REM Licensed Material - Property of IBM
@REM 
@REM 5724-M24
@REM 
@REM Copyright IBM Corp. 2009, 2016.  All rights reserved.
@REM 
@REM US Government Users Restricted Rights - Use, duplication or
@REM disclosure restricted by GSA ADP Schedule Contract with IBM
@REM Corp.
@REM ***************************************************************
@echo off

setlocal

IF "%1" == "" GOTO USAGE
IF "%1" == "-?" GOTO USAGE
IF "%1" == "-help" GOTO USAGE

echo.
echo Start to run Business Space data migration script
echo.

GOTO Loop
@REM #######################################################
@REM #                                                     #
@REM # IVT Usage                                           #
@REM #                                                     #
@REM #######################################################
:USAGE
  echo.
  echo  migrateBSpaceData -host ^<host name^> -port ^<SOAP port^>
  echo                    -user ^<server user id^> -password  ^<server password^>
  echo                    -server ^<server name^> -node  ^<node name^>
  echo                    -cluster ^<cluster name^> 
  echo                    -dbcopy  -dbupgrade
  echo.
  echo  where:  
  echo.
  echo   -host ^<host name^>:
  echo       The host name of Business Space server you connect to.
  echo.
  echo   -port ^<SOAP port^>:
  echo       The SOAP port of Business Space server you connect to.
  echo.
  echo   -user ^<user name^>:
  echo       The Business Space administrative user.
  echo.
  echo   -password  ^<user password^>:
  echo       The password of the Business Space administrative user.
  echo.
  echo   -server ^<server name^>:
  echo       Name of server, for data migration from V6.2.x in stand-alone environment.
  echo.
  echo   -node  ^<node name^>:
  echo       Name of node, for data migration from V6.2.x to in stand-alone environment.
  echo.
  echo   -cluster ^<cluster name^>:
  echo       Name of cluster, for data migration from V6.2.x in network deployment environment.
  echo.
  echo   -dbcopy:
  echo       Copy Business Space data from V7.0.x.
  echo.
  echo   -dbupgrade:
  echo       Upgrade Business Space data from V7.0.x.
  echo.    
  GOTO DONE  
  
  
@REM #######################################################
@REM #                                                     #
@REM # Read command line options                           #
@REM #                                                     #
@REM #######################################################
:Loop
IF "%1" == "" GOTO Continue
IF "%1" == "-host" (
  set hostname=%2
  GOTO Forward
)
IF "%1" == "-port" (
  set portNumber=%2
  GOTO Forward
)
IF "%1" == "-user" (
  set userID=%2
  GOTO Forward
)
IF "%1" == "-password" (
  set password=%2
  GOTO Forward
)
IF "%1" == "-server" (
  set server=%2
  GOTO Forward
)
IF "%1" == "-node" (
  set node=%2
  GOTO Forward
)
IF "%1" == "-cluster" (
  set cluster=%2
  GOTO Forward
)
IF "%1" == "-dbcopy" (
  set type="dbcopy"
  shift /1
  GOTO Loop
)
IF "%1" == "-dbupgrade" (
  set type="dbupgrade"
  shift /1
  GOTO Loop
)

echo ERROR: Invalid parameter: %1
GOTO USAGE

:Forward
shift /1
shift /1
GOTO Loop
:Continue

@REM #######################################################
@REM #                                                     #
@REM # Validate parameters                                 #
@REM #                                                     #
@REM #######################################################

IF %hostname%. == . (
  echo ERROR: Missing or invalid parameter: host
  echo.
  echo Command example for migration from Business Space V6.2.x: 
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
  echo.
  echo Command example for migration from Business Space V7.0.x:
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
  GOTO DONE
)
@REM echo hostname=%hostname%

IF %portNumber%. == . (
  echo ERROR: Missing or invalid parameter: port
  echo.
  echo Command example for migration from Business Space V6.2.x: 
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
  echo.
  echo Command example for migration from Business Space V7.0.x:
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
  GOTO DONE
)
@REM echo portNumber=%portNumber%

IF %userID%. == . (
  echo ERROR: Missing or invalid parameter: user
  echo.
  echo Command example for migration from Business Space V6.2.x: 
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
  echo.
  echo Command example for migration from Business Space V7.0.x:
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
  GOTO DONE
)
@REM echo userID=%userID%

IF %password%. == . (
  echo Command example for migration from Business Space V6.2.x: 
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
  echo.
  echo Command example for migration from Business Space V7.0.x:
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
  echo Or
  echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
  GOTO DONE
)
@REM echo password=%password%

IF %server%. == . (
  IF %cluster%. == . (
  	IF %type%. == . (
	    echo ERROR: Missing or invalid parameter: server, node, cluster or dbcopy, dbupgrade
	    echo.
		echo Command example for migration from Business Space V6.2.x: 
		echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
		echo Or
		echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
		echo.
		echo Command example for migration from Business Space V7.0.x:
		echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
		echo Or
		echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
		GOTO DONE
    )
  )
)

IF %cluster%. NEQ . (
  IF %type%. NEQ . (
    echo ERROR: Invalid or redundant parameter: server, node, cluster and dbcopy, dbupgrade can't be entered together
    echo.
	echo Command example for migration from Business Space V6.2.x: 
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
	echo Or
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
	echo.
	echo Command example for migration from Business Space V7.0.x:
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
	echo Or
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
	GOTO DONE  
  )
)	

IF %server%. NEQ . (
  IF %type%. NEQ . (
    echo ERROR: Invalid or redundant parameter: server, node, cluster and dbcopy, dbupgrade can't be entered together
    echo.
	echo Command example for migration from Business Space V6.2.x: 
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
	echo Or
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
	echo.
	echo Command example for migration from Business Space V7.0.x:
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
	echo Or
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
	GOTO DONE  
  )
)	

IF %server%. NEQ . (
  IF %cluster%. NEQ . (
    echo ERROR: Invalid or redundant parameter: server and cluster can't be entered together
    echo.
	echo Command example for migration from Business Space V6.2.x: 
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -server server1 -node leoNode01
	echo Or
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -cluster cluster1
	echo.
	echo Command example for migration from Business Space V7.0.x:
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbcopy
	echo Or
	echo    migrateBSpaceData.bat -host localhost -port 8880 -user admin -password admin -dbupgrade
	GOTO DONE  
  )
)
@REM echo server=%server%
@REM echo node=%node%
@REM echo cluster=%cluster%

set CUR_DIR=%cd%
cd /d "%~dp0\..\.."
set WASHOME=%cd%
cd /d "%CUR_DIR%"
call "%WASHOME%\bin\setupCmdLine.bat"


echo.
@REM echo call migrateBSpaceData.jy
set LOG_DIR=%WASHOME%\logs\migration
IF NOT EXIST "%LOG_DIR%" MKDIR "%LOG_DIR%"

IF %server%. NEQ . (
 "%WASHOME%"\bin\wsadmin -connType SOAP -host %hostname% -port %portNumber% -user %userID% -password %password% -lang jython -f "%WASHOME%"\BusinessSpace\scripts\migrateBSpaceData.jy %server% %node%
  GOTO DONE
)
IF %cluster%. NEQ . (
 "%WASHOME%"\bin\wsadmin -connType SOAP -host %hostname% -port %portNumber% -user %userID% -password %password% -lang jython -f "%WASHOME%"\BusinessSpace\scripts\migrateBSpaceData.jy %cluster%
  GOTO DONE
)
IF %type%. NEQ . (
 "%WASHOME%"\bin\wsadmin -connType SOAP -host %hostname% -port %portNumber% -user %userID% -password %password% -lang jython -f "%WASHOME%"\BusinessSpace\scripts\migrateBSpaceData.jy %type% %userID% %portNumber%
  GOTO DONE
)

:DONE
@REM echo "Done"
endlocal
@echo on